@@ -2,7 +2,7 @@ import logging
 import re
 import unittest
 
-from midtrans_python_rest_sdk import midtrans_python_rest_sdk as midtrans
+import midtrans_python_rest_sdk as midtrans
 
 
 # Logging
